@@ -32,7 +32,6 @@ class Engine(object):
             verbose=1,
             is_save=1,
             rootid=0,
-            session=0,
             standard_score=2,  # None代表 根据tournament_size保留种群  standard_score保留种群
             out_dir='result',
             backup_cycle=0,  # 后备数据周期，主要用于在时间序列上的问题
@@ -72,9 +71,6 @@ class Engine(object):
         self._rootid = int(
             time.time() * 1000000 +
             datetime.datetime.now().microsecond) if rootid == 0 else rootid
-        self._session = int(
-            time.time() * 1000000 +
-            datetime.datetime.now().microsecond) if session == 0 else session
         self._save_model = self.save_model if save_model is None else save_model
 
     def run_gentic(self, total_data):
@@ -104,7 +100,6 @@ class Engine(object):
             convergence=self._convergence,  # 收敛值，若为None，则不需要收敛值。
             low_memory=self._low_memory,
             fitness=self._fitness,
-            session=self._session,
             random_state=self._random_state,
             custom_params=self._custom_params,
             save_model=self._save_model)
