@@ -169,7 +169,7 @@ class Operators(object):
     def __init__(self):
 
         # 时间序列默认周期列表
-        self._ts_period = [2, 4, 6, 8, 10]
+        self._ts_period = [i for i in range(1, 22) if (i % 2) == 0]
 
         self._init_cs()
         self._init_ts()
