@@ -31,7 +31,6 @@ class Engine(object):
             standard_score=0.9,  # None代表 根据tournament_size保留种群  standard_score保留种群
             custom_params=None,
             rootid=0,
-            session=0,
             verbose=1):
 
         self._population_size = population_size
@@ -59,9 +58,6 @@ class Engine(object):
         self._rootid = int(
             time.time() * 1000000 +
             datetime.datetime.now().microsecond) if rootid == 0 else rootid
-        self._session = int(
-            time.time() * 1000000 +
-            datetime.datetime.now().microsecond) if session == 0 else session
 
     def run_gentic(self, features, X, Y, mode, n_splits):
         gentic = Gentic(
@@ -82,7 +78,6 @@ class Engine(object):
             greater_is_better=self._greater_is_better,  #True 倒序， False 正序
             convergence=self._convergence,
             rootid=self._rootid,
-            session=self._session,
             standard_score=self.
             _standard_score,  # None代表 根据tournament_size保留种群  standard_score保留种群
             verbose=self._verbose)
