@@ -1,9 +1,11 @@
+import pdb
 import pandas as pd
 from sklearn.model_selection import KFold
 from ultron.optimize.model.modelbase import load_module
 
 
-def model_fitness(features, model_name, X, Y, params, mode, n_splits):
+def model_fitness(features, model_name, X, Y, params, default_value, mode,
+                  n_splits):
     kf = KFold(n_splits=n_splits, shuffle=False)
     res = []
     for train_index, test_index in kf.split(X):
@@ -13,12 +15,6 @@ def model_fitness(features, model_name, X, Y, params, mode, n_splits):
         y_test = Y.iloc[test_index].values
         model = load_module(model_name)(features=features, **params)
         model.fit(x_train, y_train)
-        res.append({
-            'score': model.score(x_test, y_test),
-            'accuracy': model.accuracy(x_test, y_test),
-            'precision': model.precision(x_test, y_test),
-            'recall': model.recall(x_test, y_test)
-        })
+        res.append({mode: model.__getattribute__(mode)(x_test, y_test)})
     result = pd.DataFrame(res)
-    mode_name = mode if mode in result.columns else 'accuracy'
-    return 0 if result.empty else result[mode_name].mean()
\ No newline at end of file
+    return default_value if result.empty else result[mode].mean()
\ No newline at end of file
