@@ -175,7 +175,6 @@ class Gentic(object):
             greater_is_better=True,  #True 倒序， False 正序
             convergence=None,
             rootid=0,
-            session=0,
             standard_score=0.9,  # None代表 根据tournament_size保留种群  standard_score保留种群
             verbose=1):
 
@@ -204,9 +203,6 @@ class Gentic(object):
         self._rootid = int(
             time.time() * 1000000 +
             datetime.datetime.now().microsecond) if rootid == 0 else rootid
-        self._session = int(
-            time.time() * 1000000 +
-            datetime.datetime.now().microsecond) if session == 0 else session
 
     def filter_programs(self, population):
         ## 保留符合条件的种群(1.种群有效 2.分数优于基准分 3.符合指定个数)
@@ -333,7 +329,7 @@ class Gentic(object):
 
             ##
             if self._save_model is not None:
-                self._save_model(gen, self._rootid, self._session,
+                self._save_model(gen, self._rootid,
                                  self._run_details['best_programs'][-1])
             if self._greater_is_better:
                 best_fitness = fitness[np.argmax(fitness)]
