@@ -16,7 +16,7 @@ if __name__ == '__main__':
     from ultron.tests.optimize.model.linearmodel import LinearModel
     from ultron.tests.optimize.model.treemodel import TreeModel
 
-    runner = Runner([Neutralize,Quantile,Standardize,Winsorize,
-                    LinearBuild,LongShortBuild,MeanVarianceBuild,Optimizers,RiskModel,
-                    Loader,ModelBase,LinearModel])
+    runner = Runner([Neutralize,Quantile,Standardize,Winsorize,LinearBuild,
+                    LongShortBuild,MeanVarianceBuild,Optimizers,RiskModel,
+                    Loader,ModelBase,LinearModel,TreeModel])
     runner.run()
\ No newline at end of file
