@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import numbers
+from datetime import datetime
+import numbers,json
 
 import numpy as np
 from joblib import cpu_count
@@ -24,4 +25,17 @@ def check_random_state(seed):
     if isinstance(seed, np.random.RandomState):
         return seed
     raise ValueError('%r cannot be used to seed a numpy.random.RandomState'
-                     ' instance' % seed)
\ No newline at end of file
+                     ' instance' % seed)
+
+class NumpyEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        elif isinstance(obj, np.floating):
+            return float(obj)
+        elif isinstance(obj, np.ndarray):
+            return obj.tolist()
+        elif isinstance(obj, datetime.datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+        else:
+            return super(NumpyEncoder, self).default(obj)
\ No newline at end of file
